use rust_mc_proto_tokio::{prelude::*, MCConnTcp, Packet, ProtocolError};

/*

    Example of receiving motd from the server
    Sends handshake, status request and receiving one

*/

async fn send_handshake(
    conn: &mut MCConnTcp,
    protocol_version: u16,
    server_address: &str,
    server_port: u16,
    next_state: u8
) -> Result<(), ProtocolError> {
    let mut packet = Packet::empty(0x00);
    packet.write_u16_varint(protocol_version).await?;
    packet.write_string(server_address).await?;
    packet.write_unsigned_short(server_port).await?;
    packet.write_u8_varint(next_state).await?;
    conn.write_packet(&packet).await
}

async fn send_status_request(conn: &mut MCConnTcp) -> Result<(), ProtocolError> {
    conn.write_packet(&Packet::empty(0x00)).await
}

async fn read_status_response(conn: &mut MCConnTcp) -> Result<String, ProtocolError> {
    conn.read_packet().await?.read_string().await
}

#[tokio::main]
async fn main() {
    let mut conn = MCConnTcp::connect("mc.hypixel.net:25565").await.unwrap();

    send_handshake(&mut conn, 765, "mc.hypixel.net", 25565, 1).await.unwrap();
    send_status_request(&mut conn).await.unwrap();

    let motd = read_status_response(&mut conn).await.unwrap();

    dbg!(motd);
}
